@@ -6,14 +6,15 @@ import os
 import tempfile
 import warnings
 
-import numpy as NP
+import numpy as np
 from collections import OrderedDict
 from numpy.random.mtrand import uniform
 
 import netCDF4
 
 # test attribute creation.
-FILE_NAME = tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name
+#FILE_NAME = tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name
+FILE_NAME = 'tst_atts.nc'
 VAR_NAME="dummy_var"
 GROUP_NAME = "dummy_group"
 DIM1_NAME="x"
@@ -26,7 +27,7 @@ STRATT = 'string attribute'
 EMPTYSTRATT = ''
 INTATT = 1
 FLOATATT = math.pi
-SEQATT = NP.arange(10)
+SEQATT = np.arange(10)
 STRINGSEQATT = ['mary ','','had ','a ','little ','lamb',]
 #ATTDICT = {'stratt':STRATT,'floatatt':FLOATATT,'seqatt':SEQATT,
 #           'stringseqatt':''.join(STRINGSEQATT), # changed in issue #770
@@ -42,7 +43,7 @@ class VariablesTestCase(unittest.TestCase):
         f = netCDF4.Dataset(self.file,'w')
         # try to set a dataset attribute with one of the reserved names.
         f.setncattr('file_format','netcdf4_format')
-        # test attribute renameing
+        # test attribute renaming
         f.stratt_tmp = STRATT
         f.renameAttribute('stratt_tmp','stratt')
         f.emptystratt = EMPTYSTRATT
@@ -106,23 +107,23 @@ class VariablesTestCase(unittest.TestCase):
             raise ValueError('This test should have failed.')
         # issue #485 (triggers segfault in C lib
         # with version 1.2.1 without pull request #486)
-        f.foo = NP.array('bar','S')
-        f.foo = NP.array('bar','U')
+        f.foo = np.array('bar','S')
+        f.foo = np.array('bar','U')
         # issue #529 write string attribute as NC_CHAR unless
         # it can't be decoded to ascii.  Add setncattr_string
         # method to force NC_STRING.
-        f.charatt = u'foo' # will be written as NC_CHAR
+        f.charatt = 'foo' # will be written as NC_CHAR
         f.setncattr_string('stringatt','bar') # NC_STRING
-        f.cafe = u'caf\xe9' # NC_STRING
-        f.batt = u'caf\xe9'.encode('utf-8') #NC_CHAR
+        f.cafe = 'caf\xe9' # NC_STRING
+        f.batt = 'caf\xe9'.encode('utf-8') #NC_CHAR
         v.setncattr_string('stringatt','bar') # NC_STRING
         # issue #882 - provide an option to always string attribute
         # as NC_STRINGs. Testing various approaches to setting text attributes...
         f.set_ncstring_attrs(True)
-        f.stringatt_ncstr = u'foo' # will now be written as NC_STRING
+        f.stringatt_ncstr = 'foo' # will now be written as NC_STRING
         f.setncattr_string('stringatt_ncstr','bar') # NC_STRING anyway
-        f.caf_ncstr = u'caf\xe9' # NC_STRING anyway
-        f.bat_ncstr = u'caf\xe9'.encode('utf-8') # now NC_STRING
+        f.caf_ncstr = 'caf\xe9' # NC_STRING anyway
+        f.bat_ncstr = 'caf\xe9'.encode('utf-8') # now NC_STRING
         g.stratt_ncstr = STRATT # now NC_STRING
         #g.renameAttribute('stratt_tmp','stratt_ncstr')
         v.setncattr_string('stringatt_ncstr','bar') # NC_STRING anyway
@@ -145,7 +146,7 @@ class VariablesTestCase(unittest.TestCase):
         # global attributes.
         # check __dict__ method for accessing all netCDF attributes.
         for key,val in ATTDICT.items():
-            if type(val) == NP.ndarray:
+            if type(val) == np.ndarray:
                 assert f.__dict__[key].tolist() == val.tolist()
             else:
                 assert f.__dict__[key] == val
@@ -162,7 +163,7 @@ class VariablesTestCase(unittest.TestCase):
         # variable attributes.
         # check __dict__ method for accessing all netCDF attributes.
         for key,val in ATTDICT.items():
-            if type(val) == NP.ndarray:
+            if type(val) == np.ndarray:
                 assert v.__dict__[key].tolist() == val.tolist()
             else:
                 assert v.__dict__[key] == val
@@ -178,19 +179,8 @@ class VariablesTestCase(unittest.TestCase):
         assert v.getncattr('foo') == 1
         assert v.getncattr('bar') == 2
         # check type of attributes using ncdump (issue #529)
-        try:  # ncdump may not be on the system PATH
-            nc_proc = subprocess.Popen(
-                ['ncdump', '-h', FILE_NAME], stdout=subprocess.PIPE)
-        except OSError:
-            warnings.warn('"ncdump" not on system path; cannot test '
-                          'read of some attributes')
-            pass
-        else:  # We do have ncdump output
-            dep = nc_proc.communicate()[0]
-            try: # python 2
-                ncdump_output = dep.split('\n')
-            except TypeError: # python 3
-                ncdump_output = str(dep,encoding='utf-8').split('\n')
+        if not os.getenv('NO_CDL'):
+            ncdump_output = f.tocdl()
             for line in ncdump_output:
                 line = line.strip('\t\n\r')
                 line = line.strip()# Must be done another time for group variables
@@ -202,7 +192,7 @@ class VariablesTestCase(unittest.TestCase):
         # check attributes in subgroup.
         # global attributes.
         for key,val in ATTDICT.items():
-            if type(val) == NP.ndarray:
+            if type(val) == np.ndarray:
                 assert g.__dict__[key].tolist() == val.tolist()
             else:
                 assert g.__dict__[key] == val
@@ -215,7 +205,7 @@ class VariablesTestCase(unittest.TestCase):
         assert g.stringseqatt == STRINGSEQATT
         assert g.stringseqatt_array == STRINGSEQATT
         for key,val in ATTDICT.items():
-            if type(val) == NP.ndarray:
+            if type(val) == np.ndarray:
                 assert v1.__dict__[key].tolist() == val.tolist()
             else:
                 assert v1.__dict__[key] == val
